@@ -1,6 +1,9 @@
+#![allow(dead_code)]
 #![allow(clippy::type_complexity)]
 #[macro_use]
 extern crate maplit;
+#[macro_use]
+extern crate lazy_static;
 
 mod elf;
 pub mod function;
@@ -27,7 +30,7 @@ use indirect_call_analyser::IndirectCallAnalyser;
 use jump_table_analyser::JumpTableAnalyser;
 use label_provider::LabelProvider;
 use mnemonic_tf_idf::MnemonicTfIdf;
-use regex::bytes::Regex;
+use regex::bytes::Regex as BytesRegex;
 use report::DisassemblyReport;
 use ring::digest::{Context, SHA256};
 use serde::{Deserialize, Serialize};
@@ -43,6 +46,11 @@ mod error;
 pub use error::Error;
 pub type Result<T> = std::result::Result<T, Error>;
 
+lazy_static! {
+    static ref BITNESS: BytesRegex = BytesRegex::new(r"(?-u)\xE8").unwrap();
+    static ref REF_ADDR: BytesRegex = BytesRegex::new(r"(?-u)0x[a-fA-F0-9]+").unwrap();
+}
+
 static CALL_INS: &[Option<&str>] = &[Some("call"), Some("ncall")];
 static CJMP_INS: &[Option<&str>] = &[
     Some("je"),
@@ -575,8 +583,7 @@ impl Disassembler {
                 .cloned()
                 .collect();
         for bitness in [32, 64] {
-            let re = Regex::new(r"(?-u)\xE8").unwrap();
-            for call_match in re.find_iter(binary) {
+            for call_match in BITNESS.find_iter(binary) {
                 if binary.len() - call_match.start() > 5 {
                     let packed_call: &[u8; 4] =
                         &binary[call_match.start() + 1..call_match.start() + 5].try_into()?;
@@ -852,8 +859,7 @@ impl Disassembler {
     }
 
     fn get_referenced_addr(&self, op_str: &str) -> Result<u64> {
-        let re = Regex::new(r"(?-u)0x[a-fA-F0-9]+").unwrap();
-        let referenced_addr = re.find_iter(op_str.as_bytes()).next();
+        let referenced_addr = REF_ADDR.find_iter(op_str.as_bytes()).next();
         if let Some(ref_addr) = referenced_addr {
             let z = u64::from_str_radix(std::str::from_utf8(&ref_addr.as_bytes()[2..])?, 16)?;
             return Ok(z);
